@@ -155,6 +155,7 @@ The rest of this section describes GD::Simple-specific methods.
 
 use strict;
 use GD;
+use GD::Group;
 use Math::Trig;
 use Carp 'croak';
 
@@ -970,6 +971,11 @@ sub RGBtoHSV {
   return ($h, $s, $v);
 }
 
+sub newGroup {
+    my $self  = shift;
+    return $self->GD::newGroup(@_);
+}
+
 1;
 
 __DATA__
